summaryrefslogtreecommitdiffstats
path: root/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
diff options
context:
space:
mode:
Diffstat (limited to 'c/src/lib/libcpu/arm/lpc22xx/timer/timer.c')
-rw-r--r--c/src/lib/libcpu/arm/lpc22xx/timer/timer.c26
1 files changed, 8 insertions, 18 deletions
diff --git a/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c b/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
index 8bc3547763..ae63fb0d84 100644
--- a/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
+++ b/c/src/lib/libcpu/arm/lpc22xx/timer/timer.c
@@ -13,8 +13,8 @@
* Notes:
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
* benchmark_timerinitialize() and benchmark_timerread(). benchmark_timerread() usually returns
* the number of microseconds since benchmark_timerinitialize() exitted.
*
* It is important that the timer start/stop overhead be determined
* when porting or modifying this code.
@@ -29,19 +29,19 @@
uint32_t g_start;
uint32_t g_freq;
-rtems_boolean benchmark_timerfind_average_overhead;
+rtems_boolean benchmark_timer_find_average_overhead;
/*
* Set up Timer 1
*/
-void benchmark_timerinitialize( void )
+void benchmark_timer_initialize( void )
{
g_freq = LPC22xx_Fpclk / 1000;
}
/*
* The following controls the behavior of benchmark_timerread().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It
* is usually deducted from the number returned.
@@ -55,7 +55,7 @@ void benchmark_timerinitialize( void )
/* This value is in microseconds. */
#define LEAST_VALID 1 /* Don't trust a clicks value lower than this */
-int benchmark_timerread( void )
+int benchmark_timer_read( void )
{
return (T0TC/(LPC22xx_Fpclk/1000000));
/*
@@ -65,20 +65,10 @@ int benchmark_timerread( void )
*/
}
-/*
- * Empty function call used in loops to measure basic cost of looping
- * in Timing Test Suite.
- */
-
-rtems_status_code benchmark_timerempty_function( void )
-{
- return RTEMS_SUCCESSFUL;
-}
-
-void benchmark_timerdisable_subtracting_average_overhead(
+void benchmark_timer_disable_subtracting_average_overhead(
rtems_boolean find_flag
)
{
- benchmark_timerfind_average_overhead = find_flag;
+ benchmark_timer_find_average_overhead = find_flag;
}
@@ -13,8 +13,8 @@
* This file manages the benchmark timer used by the RTEMS Timing Test
* Suite. Each measured time period is demarcated by calls to
- * benchmark_timerinitialize() and benchmark_timerread(). benchmark_timerread() usually returns
- * the number of microseconds since benchmark_timerinitialize() exitted.
+ * benchmark_timer_initialize() and benchmark_timer_read(). benchmark_timer_read() usually returns
+ * the number of microseconds since benchmark_timer_initialize() exitted.
*
* It is important that the timer start/stop overhead be determined
@@ -29,19 +29,19 @@
}
/*
- * The following controls the behavior of benchmark_timerread().
+ * The following controls the behavior of benchmark_timer_read().
*
* AVG_OVEREHAD is the overhead for starting and stopping the timer. It